/**
 * vue-promise-blocks v0.0.1
 * (c) 2018 Eduardo San Martin Morote
 * @license MIT
 */

'use strict';

var index = {
  name: 'PromiseBlock',
  props: {
    promise: Promise,
    promises: Array,
  },

  data: function () { return ({
    resolved: false,
    data: null,
    error: null,
  }); },

  render: function render(h) {
    if (this.error instanceof Error || (this.error && this.error.length)) {
      return this.$scopedSlots.error(this.error);
    } else if (this.resolved) {
      return this.$scopedSlots.default(this.data);
    } else {
      return this.$slots.default[0];
    }
  },

  watch: {
    promise: {
      handler: function handler(promise) {
        var this$1 = this;

        if (!promise) { return; }
        this.resolved = false;
        this.error = null;
        promise
          .then(function (data) {
            if (this$1.promise === promise) {
              this$1.resolved = true;
              this$1.data = data;
            }
          })
          .catch(function (err) {
            if (this$1.promise === promise) { this$1.error = err; }
          });
      },
      immediate: true,
    },

    promises: {
      handler: function handler(promises) {
        var this$1 = this;

        if (!promises) { return; }
        this.resolved = false;
        this.error = [];
        this.data = [];
        promises.forEach(function (p) {
          p
            .then(function (data) {
              if (this$1.promises === promises) {
                this$1.resolved = true;
                this$1.data.push(data);
              }
            })
            .catch(function (err) {
              if (this$1.promises === promises) { this$1.error.push(err); }
            });
        });
      },
      immediate: true,
    },
  },
};

module.exports = index;
